OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendario",
    "Tasks" : "Tareas",
    "Personal" : "Personal",
    "{actor} created calendar {calendar}" : "{actor} creó el calendario {calendar}",
    "You created calendar {calendar}" : "Creaste el calendario {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} borró el calendario {calendar}",
    "You deleted calendar {calendar}" : "Borraste el calendario {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} actualizó el calendario {calendar}",
    "You updated calendar {calendar}" : "Actualizaste el calendario {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} restauró el calendario {calendar}",
    "You restored calendar {calendar}" : "Restauraste el calendario {calendar}",
    "You shared calendar {calendar} as public link" : "Compartiste el calendario {calendar} como una liga pública",
    "You removed public link for calendar {calendar}" : "Eliminaste la liga pública para el calendario {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} ha compartido el calendario {calendar} contigo",
    "You shared calendar {calendar} with {user}" : "Compartiste el calendario {calendar} con {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} compartió el calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} ha dejado de compartir el calendario {calendar} contigo",
    "You unshared calendar {calendar} from {user}" : "Has dejado de compartir el calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} dejó de compartir el calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} dejó de compartir {calendar} con él mismo",
    "You shared calendar {calendar} with group {group}" : "Compartiste el calendario {calendar} con el grupo {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} compartió el calendario {calendar} con el grupo {group}",
    "You unshared calendar {calendar} from group {group}" : "Dejaste de compartir el calendario {calendar} con el grupo {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} dejó de compartir el calendrio {calendar} con el grupo {group}",
    "Untitled event" : "Evento sin título",
    "{actor} created event {event} in calendar {calendar}" : "{actor} creó el evento {event} en el calendario {calendar}",
    "You created event {event} in calendar {calendar}" : "Creaste el evento {event} en el calendario {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} borró el eventó {event} del calendario {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Borraste el evento {event} del calendario {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} actualizó el evento {event} en el calendario {calendar}",
    "You updated event {event} in calendar {calendar}" : "Actualizaste el evento {event} en el calendario {calendar}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} movió el evento {event} del calendario {targetCalendar} al calendario {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Moviste el evento {event} del calendario {targetCalendar} al calendario {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} restauró el evento {event} del calendario {calendar}",
    "You restored event {event} of calendar {calendar}" : "Restauraste el evento {event} del calendario {calendar}",
    "Busy" : "Ocupado",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} creó la tarea {todo} en la lista {calendar}",
    "You created to-do {todo} in list {calendar}" : "Creaste la tarea {todo} en la lista {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} eliminó la tarea {todo} de la lista {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "Eliminaste la tarea {todo} de la lista {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} actualizó la tarea {todo} en la lista {calendar}",
    "You updated to-do {todo} in list {calendar}" : "Actualizaste la tarea {todo} en la lista {calendar}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} marcó como resuelta la tarea {todo} en la lista {calendar}",
    "You solved to-do {todo} in list {calendar}" : "Marcaste como resuelta la tarea {todo} en la lista {calendar}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} reabrió la tarea {todo} en la lista {calendar}",
    "You reopened to-do {todo} in list {calendar}" : "Reabriste la tarea {todo} en la lista {calendar}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} movió la tarea {todo} de la lista {targetCalendar} a la lista {targetCalendar}",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Moviste la tarea {todo} de la lista {targetCalendar} a la lista {targetCalendar}",
    "Calendar, contacts and tasks" : "Calendario, contactos y tareas",
    "A <strong>calendar</strong> was modified" : "Un <strong>calendario</strong> fue modificado",
    "A calendar <strong>event</strong> was modified" : "Un <strong>evento</strong> de un calendario fue modificado",
    "A calendar <strong>to-do</strong> was modified" : "Se modificó una tarea en el calendario",
    "Contact birthdays" : "Cumpleaños del contacto",
    "Death of %s" : "Fallecimiento de %s",
    "Untitled calendar" : "Calendario sin título",
    "Calendar:" : "Calendario:",
    "Date:" : "Fecha:",
    "Where:" : "Dónde:",
    "Description:" : "Descripción:",
    "_%n year_::_%n years_" : ["%n year","%n years","%n years"],
    "_%n month_::_%n months_" : ["%n month","%n months","%n months"],
    "_%n day_::_%n days_" : ["%n day","%n days","%n days"],
    "_%n hour_::_%n hours_" : ["%n hora","%n horas","%n horas"],
    "_%n minute_::_%n minutes_" : ["%n minuto","%n minutos","%n minutos"],
    "%s (in %s)" : "%s (en %s)",
    "%s (%s ago)" : "%s (%s atrás)",
    "Calendar: %s" : "Calendario: %s",
    "Date: %s" : "Fecha: %s",
    "Description: %s" : "Descripción: %s",
    "Where: %s" : "Lugar: %s",
    "%1$s via %2$s" : "%1$s a través de %2$s",
    "Cancelled: %1$s" : "Cancelado: %1$s",
    "\"%1$s\" has been canceled" : "\"%1$s\" ha sido cancelado",
    "Re: %1$s" : "Re: %1$s",
    "%1$s has accepted your invitation" : "%1$s ha aceptado tu invitación",
    "%1$s has tentatively accepted your invitation" : "%1$s ha aceptado tu invitación tentativamente",
    "%1$s has declined your invitation" : "%1$s ha rechazado tu invitación",
    "%1$s has responded to your invitation" : "%1$s ha respondido a tu invitación",
    "Invitation updated: %1$s" : "Invitación actualizada: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s actualizó el evento \"%2$s\"",
    "Invitation: %1$s" : "Invitación: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s te invita a \"%2$s\"",
    "Organizer:" : "Organizador:",
    "Attendees:" : "Asistentes:",
    "Title:" : "Título:",
    "When:" : "Cuándo:",
    "Location:" : "Ubicación:",
    "Link:" : "Enlace:",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "More options …" : "Más opciones...",
    "More options at %s" : "Más opciones en %s",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Sunday" : "Domingo",
    "January" : "Enero",
    "February" : "Febrero",
    "March" : "Marzo",
    "April" : "Abril",
    "May" : "Mayo",
    "June" : "Junio",
    "July" : "Julio",
    "August" : "Agosto",
    "September" : "Septiembre",
    "October" : "Octubre",
    "November" : "Noviembre",
    "December" : "Diciembre",
    "First" : "Primero",
    "Last" : "Último",
    "Contacts" : "Contactos",
    "{actor} created address book {addressbook}" : "{actor} creó la libreta de direcciones {addressbook}",
    "You created address book {addressbook}" : "Creaste la libreta de direcciones {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} eliminó la libreta de direcciones {addressbook}",
    "You deleted address book {addressbook}" : "Eliminaste la libreta de direcciones {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} actualizó la libreta de direcciones {addressbook}",
    "You updated address book {addressbook}" : "Actualizaste la libreta de direcciones {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} compartió contigo la libreta de direcciones {addressbook}",
    "You shared address book {addressbook} with {user}" : "Compartiste la libreta de direcciones {addressbook} con {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} compartió la libreta de direcciones {addressbook} con {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} dejó de compartir contigo la libreta de direcciones {addressbook}",
    "You unshared address book {addressbook} from {user}" : "Dejaste de compartir la libreta de direcciones {addressbook} con {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} dejó de compartir la libreta de direcciones {addressbook} con {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} dejó de compartir la libreta de direcciones {addressbook} consigo mismo",
    "You shared address book {addressbook} with group {group}" : "Compartiste la libreta de direcciones {addressbook} con el grupo {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} compartió la libreta de direcciones {addressbook} con el grupo {group}",
    "You unshared address book {addressbook} from group {group}" : "Dejaste de compartir la libreta de direcciones {addressbook} con el grupo {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} dejó de compartir la libreta de direcciones {addressbook} con el grupo {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} creó el contacto {card} en la libreta de direcciones {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Creaste el contacto {card} en la libreta de direcciones {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} eliminó el contacto {card} de la libreta de direcciones {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Eliminaste el contacto {card} de la libreta de direcciones {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} actualizó el contacto {card} en la libreta de direcciones {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Actualizaste el contacto {card} en la libreta de direcciones {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Se modificó un contacto o una libreta de direcciones",
    "Accounts" : "Cuentas",
    "System address book which holds all accounts" : "Libreta de direcciones del sistema que contiene todas las cuentas",
    "File is not updatable: %1$s" : "No se puede actualizar el archivo: %1$s",
    "Could not write to final file, canceled by hook" : "No se pudo escribir en el archivo final, cancelado por el gancho",
    "Could not write file contents" : "No se pudo escribir el contenido del archivo",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes","%n bytes"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Error al copiar el archivo a la ubicación de destino (copiado: %1$s, tamaño de archivo esperado: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Tamaño de archivo esperado de %1$s, pero se leyó (desde el cliente de Nextcloud) y se escribió (en el almacenamiento de Nextcloud) %2$s. Puede ser un problema de red en el lado del envío o un problema de escritura en el almacenamiento en el lado del servidor.",
    "Could not rename part file to final file, canceled by hook" : "No se pudo renombrar el archivo parcial al archivo final, cancelado por el gancho",
    "Could not rename part file to final file" : "No se pudo renombrar el archivo parcial al archivo final",
    "Failed to check file size: %1$s" : "Error al verificar el tamaño del archivo: %1$s",
    "Encryption not ready: %1$s" : "La encriptación no está lista: %1$s",
    "Failed to open file: %1$s" : "Error al abrir el archivo: %1$s",
    "Failed to unlink: %1$s" : "Error al eliminar: %1$s",
    "Failed to write file contents: %1$s" : "Error al escribir el contenido del archivo: %1$s",
    "File not found: %1$s" : "Archivo no encontrado: %1$s",
    "System is in maintenance mode." : "El sistema está en modo de mantenimiento.",
    "Upgrade needed" : "Se necesita una actualización",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Tu %s debe configurarse para usar HTTPS para utilizar CalDAV y CardDAV con iOS/macOS.",
    "Configures a CalDAV account" : "Configura una cuenta CalDAV",
    "Configures a CardDAV account" : "Configura una cuenta CardDAV",
    "Events" : "Eventos",
    "Untitled task" : "Tarea sin título",
    "Completed on %s" : "Completada el %s",
    "Due on %s by %s" : "Vence el %s a las %s",
    "Due on %s" : "Vence el %s",
    "WebDAV endpoint" : "Extremo WebDAV",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Tu servidor web aún no esta correctamente configurado para permitir la sincronización de archivos porque la interfaz WebDAV parece estar rota. ",
    "Migrated calendar (%1$s)" : "Calendario migrado (%1$s)",
    "Calendars including events, details and attendees" : "Calendarios que incluyen eventos, detalles y asistentes",
    "Contacts and groups" : "Contactos y grupos",
    "WebDAV" : "WebDAV",
    "First day" : "Primer día",
    "Save" : "Guardar",
    "Failed to load availability" : "Error al cargar la disponibilidad",
    "Saved availability" : "Disponibilidad guardada",
    "Failed to save availability" : "Error al guardar la disponibilidad",
    "Time zone:" : "Zona horaria:",
    "to" : "para",
    "Delete slot" : "Eliminar ranura",
    "No working hours set" : "No se han establecido horas de trabajo",
    "Add slot" : "Agregar ranura",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Configurar automáticamente el estado del usuario como \"No molestar\" fuera de la disponibilidad para silenciar todas las notificaciones.",
    "Availability" : "Disponibilidad",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "También instala la {calendarappstoreopen}aplicación Calendario{linkclose}, o {calendardocopen}conecta tu escritorio y móvil para sincronizar ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Asegúrate de configurar correctamente {emailopen}el servidor de correo electrónico{linkclose}.",
    "Calendar server" : "Servidor de calendario",
    "Send invitations to attendees" : "Enviar invitaciones a los asistentes",
    "Automatically generate a birthday calendar" : "Generar automaticamente un calendario para cumpleaños",
    "Birthday calendars will be generated by a background job." : "Los calendarios de cumpleaños serán generados por un trabajo de segundo plano",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Por lo tanto no estarán disponbiles inmediatamente después de habilitarlos pero se mostrarán después de un tiempo.",
    "Send notifications for events" : "Enviar notificaciones para eventos",
    "Notifications are sent via background jobs, so these must occur often enough." : "Las notificaciones se envían a través de trabajos en segundo plano, por lo que deben ocurrir con la suficiente frecuencia.",
    "Send reminder notifications to calendar sharees as well" : "Enviar recordatorios a los asistentes del calendario también",
    "Reminders are always sent to organizers and attendees." : "Los recordatorios siempre se envían a los organizadores y asistentes.",
    "Enable notifications for events via push" : "Habilitar notificaciones para eventos mediante push",
    "Cancel" : "Cancelar",
    "Import" : "Importar",
    "Error while saving settings" : "Error al guardar la configuración.",
    "There was an error updating your attendance status." : "Hubo un error al actualizar tu estado de asistencia.",
    "Please contact the organizer directly." : "Por favor, contacta directamente al organizador.",
    "Are you accepting the invitation?" : "¿Aceptas la invitación?",
    "Tentative" : "Tentativo",
    "Your attendance was updated successfully." : "Tu asistencia se actualizó correctamente."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
